<?php

namespace Drupal\dblog_filter\Logger;

use Drupal\Core\Config\ConfigFactoryInterface;
use Drupal\Core\Logger\LogMessageParserInterface;
use Drupal\Core\Logger\RfcLoggerTrait;
use Drupal\Core\Logger\RfcLogLevel;
use Drupal\syslog\Logger\SysLog;

/**
 * Class SyslogFilter to add log messages.
 *
 * @package Drupal\dblog_filter
 */
class SyslogFilter extends SysLog {

  use RfcLoggerTrait;

  /**
   * The config factory.
   *
   * @var \Drupal\Core\Config\ConfigFactoryInterface
   */
  protected $configFactory;

  /**
   * Constructs a SysLog object.
   *
   * @param \Drupal\Core\Config\ConfigFactoryInterface $config_factory
   *   The configuration factory object.
   * @param \Drupal\Core\Logger\LogMessageParserInterface $parser
   *   The parser to use when extracting message variables.
   */
  public function __construct(ConfigFactoryInterface $config_factory, LogMessageParserInterface $parser) {
    parent::__construct($config_factory, $parser);
    $this->configFactory = $config_factory;
  }

  /**
   * {@inheritdoc}
   */
  public function log($level, $message, array $context = []) {
    $result = FALSE;
    // Get RFC Log levels.
    $levels = RfcLogLevel::getLevels();
    $format = $this->config->get('format');
    $sysfilterConfig = $this->configFactory->get('dblog_filter.settings');
    $severity_levels = $sysfilterConfig->get('syslog_severity_levels');
    $method = $sysfilterConfig->get('syslog_method') ?: 'include';

    // If no format is configured then a message will not be written to syslog
    // so return early. This occurs during installation of the syslog module
    // before configuration has been written.
    if (empty($format)) {
      return;
    }
    // Ensure we have a connection available.
    $this->openConnection();

    foreach ($levels as $key => $log_level) {
      $level_array[$key] = strtolower($log_level->getUntranslatedString());
    }

    if (!empty($severity_levels[$level_array[$level]])) {
      $result = TRUE;
    }
    // If present the only log message.
    if ($method == 'exclude') {
      $result = !$result;
    }
    if ($result) {
      parent::log($level, $message, $context);
    }
  }

}
